export = index;
/**
 * @param  {ConstructorParameters<typeof CssUsageDuplex>} options
 * @return {CssUsageDuplex}
 */
declare function index(options: {
    browsers: string;
    ignore?: FeatureKeys[];
    skipErrors?: boolean;
}, filename?: string): CssUsageDuplex;
declare namespace index {
    export { FeatureCheck, RuleCheck, Feature, Filter, MissingSupportResultStats, BrowserSupportStats, MissingSupportResult, DetectorCallbackArgument, DetectorCallback, FeatureKeys, OnFeatureUsageArguments, OnFeatureUsage, DoIUseOptions, SourceMapTransformation };
}
type FeatureKeys = import('../data/features.js').FeatureKeys;
declare const CssUsageDuplex_base: any;
/** @typedef {import('../../data/features.js').FeatureKeys} FeatureKeys */
declare class CssUsageDuplex extends CssUsageDuplex_base {
    [x: string]: any;
    /**
     * @param {Object} options
     * @param {string} options.browsers
     * @param {FeatureKeys[]} [options.ignore]
     * @param {boolean} [options.skipErrors]
     * @param {string} [filename] Filename for outputting source code locations.
     */
    constructor(options: {
        browsers: string;
        ignore?: FeatureKeys[];
        skipErrors?: boolean;
    }, filename?: string);
}
type FeatureCheck = string | RegExp | ((value: string) => boolean);
type RuleCheck = (rule: import('postcss').ChildNode) => boolean;
type Feature = Record<string, FeatureCheck | FeatureCheck[] | boolean> | RuleCheck | RuleCheck[];
type Filter<T> = {
    missing: T;
    partial: T;
};
type MissingSupportResultStats = {
    title: string;
    caniuseData: caniuse.Feature;
    missing?: string;
    missingData?: Record<string, Record<string, string>>;
    partial?: string;
    partialData?: Record<string, Record<string, string>>;
};
type BrowserSupportStats = Partial<Record<keyof FEATURES, MissingSupportResultStats>>;
type MissingSupportResult = {
    browsers: string[][];
    features: Partial<Record<keyof FEATURES, MissingSupportResultStats>>;
};
type DetectorCallbackArgument = {
    usage: import('postcss').ChildNode;
    feature: keyof FEATURES;
    ignore: (keyof FEATURES & string)[];
};
type DetectorCallback = (result: DetectorCallbackArgument) => any;
type OnFeatureUsageArguments = {
    feature: FeatureKeys;
    featureData: any | undefined;
    usage: import('postcss').Node;
    message: string;
};
type OnFeatureUsage = (result: OnFeatureUsageArguments) => any;
type DoIUseOptions = {
    browsers?: [query?: string | string[], from?: string | false][0];
    ignore?: FeatureKeys[];
    onFeatureUsage?: OnFeatureUsage;
    ignoreFiles?: string[];
};
type SourceMapTransformation = any;
import caniuse = require("caniuse-lite");
type FEATURES = Feature;
/** @typedef {RegExp|string|((value:string) => boolean)} FeatureCheck */
/** @typedef {((rule:import('postcss').ChildNode) => boolean)} RuleCheck */
/** @typedef {Record<string, FeatureCheck|FeatureCheck[]|boolean> | RuleCheck | RuleCheck[]} Feature */
/** @enum {Feature} */
declare const FEATURES: {
    'alternate-stylesheet': any;
    'background-attachment': any;
    'background-clip-text': any;
    'background-img-opts': {
        'background-clip': boolean;
        'background-origin': boolean;
        'background-size': boolean;
    };
    'background-position-x-y': {
        'background-position-x': boolean;
        'background-position-y': boolean;
    };
    'background-repeat-round-space': any;
    'border-image': {
        'border-image': boolean;
        'border-image-outset': boolean;
        'border-image-repeat': boolean;
        'border-image-slice': boolean;
        'border-image-source': boolean;
        'border-image-width': boolean;
    };
    'border-radius': {
        'border-radius': boolean;
        'border-top-left-radius': boolean;
        'border-top-right-radius': boolean;
        'border-bottom-right-radius': boolean;
        'border-bottom-left-radius': boolean;
    };
    calc: {
        '': string;
    };
    'ch-unit': any;
    'css-all': {
        all: boolean;
    };
    'css-animation': {
        animation: boolean;
        'animation-name': boolean;
        'animation-duration': boolean;
        'animation-timing-function': boolean;
        'animation-iteration-count': boolean;
        'animation-direction': boolean;
        'animation-play-state': boolean;
        'animation-delay': boolean;
        'animation-fill-mode': boolean;
    };
    'css-any-link': (rule: import('postcss').ChildNode) => boolean;
    'css-appearance': {
        appearance: boolean;
        '-webkit-appearance': boolean;
        '-moz-appearance': boolean;
    };
    'css-at-counter-style': (rule: import('postcss').ChildNode) => boolean;
    'css-autofill': (rule: import('postcss').ChildNode) => boolean;
    'css-backdrop-filter': {
        'backdrop-filter': boolean;
    };
    'css-background-offsets': (rule: import('postcss').ChildNode) => boolean;
    'css-backgroundblendmode': {
        'background-blend-mode': boolean;
    };
    'css-boxdecorationbreak': any;
    'css-boxshadow': {
        'box-shadow': boolean;
    };
    'css-canvas': (rule: import('postcss').ChildNode) => boolean;
    'css-caret-color': any;
    'css-cascade-layers': any;
    'css-case-insensitive': any;
    'css-clip-path': {
        'clip-path': boolean;
    };
    'css-color-adjust': any;
    'css-color-function': any;
    'css-conic-gradients': {
        background: RegExp;
        'background-image': RegExp;
        'border-image': RegExp;
        'border-image-source': RegExp;
        content: RegExp;
        cursor: RegExp;
        'list-style': RegExp;
        'list-style-image': RegExp;
    };
    'css-container-queries': any;
    'css-container-queries-style': (rule: import('postcss').ChildNode) => boolean;
    'css-container-query-units': (rule: import('postcss').ChildNode) => boolean;
    'css-containment': any;
    'css-content-visibility': any;
    'css-counters': {
        'counter-reset': boolean;
        'counter-increment': boolean;
        '': string;
    };
    'css-crisp-edges': any;
    'css-cross-fade': any;
    'css-default-pseudo': any;
    'css-descendant-gtgt': any;
    'css-deviceadaptation': any;
    'css-dir-pseudo': any;
    'css-display-contents': any;
    'css-element-function': any;
    'css-env-function': {
        '': string;
    };
    'css-exclusions': any;
    'css-featurequeries': (rule: import('postcss').ChildNode) => boolean;
    'css-file-selector-button': any;
    'css-filter-function': any;
    'css-filters': {
        filter: boolean;
    };
    'css-first-letter': any;
    'css-first-line': any;
    'css-fixed': {
        position: string;
    };
    'css-focus-visible': any;
    'css-focus-within': any;
    'css-font-palette': ((rule: any) => any)[];
    'css-font-rendering-controls': any;
    'css-font-stretch': {
        'font-stretch': boolean;
    };
    'css-gencontent': (rule: import('postcss').ChildNode) => boolean;
    'css-gradients': {
        background: RegExp;
        'background-image': RegExp;
        'border-image': RegExp;
        'border-image-source': RegExp;
        content: RegExp;
        cursor: RegExp;
        'list-style': RegExp;
        'list-style-image': RegExp;
    };
    'css-grid': {
        display: string[];
        grid: boolean;
        'grid-area': boolean;
        'grid-auto-columns': boolean;
        'grid-auto-flow': boolean;
        'grid-auto-rows': boolean;
        'grid-column': boolean;
        'grid-column-end': boolean;
        'grid-column-start': boolean;
        'grid-row': boolean;
        'grid-row-end': boolean;
        'grid-row-start': boolean;
        'grid-template': boolean;
        'grid-template-areas': boolean;
        'grid-template-columns': boolean;
        'grid-template-rows': boolean;
    };
    'css-grid-animation': {
        transition: RegExp;
        'transition-property': RegExp;
    };
    'css-hanging-punctuation': any;
    'css-has': any;
    'css-hyphens': {
        hyphens: boolean;
    };
    'css-image-orientation': {
        'image-orientation': boolean;
    };
    'css-image-set': any;
    'css-in-out-of-range': any;
    'css-indeterminate-pseudo': any;
    'css-initial-letter': any;
    'css-initial-value': {
        '': string;
    };
    'css-lch-lab': any;
    'css-letter-spacing': any;
    'css-line-clamp': any;
    'css-logical-props': {
        'block-size': boolean;
        'inline-size': boolean;
        'min-block-size': boolean;
        'min-inline-size': boolean;
        'max-block-size': boolean;
        'max-inline-size': boolean;
        'margin-block-start': boolean;
        'margin-block-end': boolean;
        'margin-inline-start': boolean;
        'margin-inline-end': boolean;
        'margin-block': boolean;
        'margin-inline': boolean;
        'inset-block-start': boolean;
        'inset-block-end': boolean;
        'inset-inline-start': boolean;
        'inset-inline-end': boolean;
        'inset-block': boolean;
        'inset-inline': boolean;
        inset: boolean;
        'padding-block-start': boolean;
        'padding-block-end': boolean;
        'padding-inline-start': boolean;
        'padding-inline-end': boolean;
        'padding-block': boolean;
        'padding-inline': boolean;
        'border-block-start-width': boolean;
        'border-block-end-width': boolean;
        'border-inline-start-width': boolean;
        'border-inline-end-width': boolean;
        'border-block-width': boolean;
        'border-inline-width': boolean;
        'border-block-start-style': boolean;
        'border-block-end-style': boolean;
        'border-inline-start-style': boolean;
        'border-inline-end-style': boolean;
        'border-block-style': boolean;
        'border-inline-style': boolean;
        'border-block-start-color': boolean;
        'border-block-end-color': boolean;
        'border-inline-start-color': boolean;
        'border-inline-end-color': boolean;
        'border-block-color': boolean;
        'border-inline-color': boolean;
        'border-block-start': boolean;
        'border-block-end': boolean;
        'border-inline-start': boolean;
        'border-inline-end': boolean;
        'border-block': boolean;
        'border-inline': boolean;
        'border-start-start-radius': boolean;
        'border-start-end-radius': boolean;
        'border-end-start-radius': boolean;
        'border-end-end-radius': boolean;
        'text-align': string[];
        float: string[];
        resize: string[];
        'overflow-block': boolean;
        'overflow-inline': boolean;
    };
    'css-marker-pseudo': any;
    'css-masks': {
        'clip-path': boolean;
        mask: boolean;
        'mask-border': boolean;
        'mask-border-mode': boolean;
        'mask-border-outset': boolean;
        'mask-border-repeat': boolean;
        'mask-border-slice': boolean;
        'mask-border-source': boolean;
        'mask-border-width': boolean;
        'mask-clip': boolean;
        'mask-composite': boolean;
        'mask-image': boolean;
        'mask-mode': boolean;
        'mask-origin': boolean;
        'mask-position': boolean;
        'mask-repeat': boolean;
        'mask-size': boolean;
        'mask-type': boolean;
        '-webkit-clip-path': boolean;
        '-webkit-mask': boolean;
        '-webkit-mask-border': boolean;
        '-webkit-mask-border-mode': boolean;
        '-webkit-mask-border-outset': boolean;
        '-webkit-mask-border-repeat': boolean;
        '-webkit-mask-border-slice': boolean;
        '-webkit-mask-border-source': boolean;
        '-webkit-mask-border-width': boolean;
        '-webkit-mask-clip': boolean;
        '-webkit-mask-composite': boolean;
        '-webkit-mask-image': boolean;
        '-webkit-mask-mode': boolean;
        '-webkit-mask-origin': boolean;
        '-webkit-mask-position': boolean;
        '-webkit-mask-repeat': boolean;
        '-webkit-mask-size': boolean;
        '-webkit-mask-type': boolean;
    };
    'css-matches-pseudo': (rule: import('postcss').ChildNode) => boolean;
    'css-math-functions': {
        '': string[];
    };
    'css-media-interaction': any;
    'css-media-range-syntax': (rule: import('postcss').ChildNode) => boolean;
    'css-media-resolution': (rule: import('postcss').ChildNode) => boolean;
    'css-media-scripting': any;
    'css-mediaqueries': (rule: import('postcss').ChildNode) => boolean;
    'css-mixblendmode': {
        'mix-blend-mode': boolean;
    };
    'css-motion-paths': {
        'offset-path': boolean;
    };
    'css-namespaces': any;
    'css-nesting': any;
    'css-not-sel-list': any;
    'css-nth-child-of': any;
    'css-opacity': {
        opacity: boolean;
    };
    'css-optional-pseudo': any;
    'css-overflow': any;
    'css-overflow-anchor': any;
    'css-overflow-overlay': {
        overflow: string;
    };
    'css-overscroll-behavior': {
        'overscroll-behavior': boolean;
        'overscroll-behavior-x': boolean;
        'overscroll-behavior-y': boolean;
    };
    'css-page-break': any;
    'css-paged-media': any;
    'css-paint-api': any;
    'css-placeholder': ((rule: import('postcss').ChildNode) => boolean)[];
    'css-placeholder-shown': any;
    'css-print-color-adjust': {
        'print-color-adjust': boolean;
    };
    'css-read-only-write': any;
    'css-rebeccapurple': any;
    'css-reflections': {
        'box-reflect': boolean;
        '-webkit-box-reflect': boolean;
    };
    'css-regions': any;
    'css-relative-colors': any;
    'css-repeating-gradients': {
        '': string[];
    };
    'css-resize': {
        resize: boolean;
    };
    'css-revert-value': {
        '': string;
    };
    'css-rrggbbaa': any;
    'css-scroll-behavior': any;
    'css-scroll-timeline': any;
    'css-scrollbar': {
        'scrollbar-color': boolean;
        'scrollbar-width': boolean;
    };
    'css-sel2': (rule: import('postcss').ChildNode) => boolean;
    'css-sel3': (rule: import('postcss').ChildNode) => boolean;
    'css-selection': (rule: import('postcss').ChildNode) => boolean;
    'css-shapes': {
        'shape-outside': boolean;
        'shape-image-threshold': boolean;
        'shape-margin': boolean;
    };
    'css-snappoints': any;
    'css-sticky': {
        position: string;
    };
    'css-subgrid': any;
    'css-supports-api': any;
    'css-table': {
        display: string[];
    };
    'css-text-align-last': any;
    'css-text-box-trim': any;
    'css-text-indent': any;
    'css-text-justify': any;
    'css-text-orientation': any;
    'css-text-spacing': any;
    'css-textshadow': {
        'text-shadow': boolean;
    };
    'css-touch-action': {
        'touch-action': boolean;
    };
    'css-transitions': {
        transition: boolean;
        'transition-property': boolean;
        'transition-duration': boolean;
        'transition-delay': boolean;
        'transition-timing-function': boolean;
    };
    'css-unicode-bidi': any;
    'css-unset-value': {
        '': string;
    };
    'css-variables': (rule: import('postcss').ChildNode) => boolean;
    'css-when-else': any;
    'css-widows-orphans': any;
    'css-width-stretch': any;
    'css-writing-mode': any;
    'css-zoom': any;
    'css3-attr': any;
    'css3-boxsizing': {
        'box-sizing': boolean;
    };
    'css3-colors': {
        '': string[];
    };
    'css3-cursors': {
        cursor: string[];
    };
    'css3-cursors-grab': {
        cursor: string[];
    };
    'css3-cursors-newer': {
        cursor: string[];
    };
    'css3-tabsize': {
        'tab-size': boolean;
    };
    currentcolor: any;
    devicepixelratio: any;
    'extended-system-fonts': any;
    flexbox: {
        display: string[];
        flex: boolean;
        'flex-grow': boolean;
        'flex-shrink': boolean;
        'flex-basis': boolean;
        'flex-direction': boolean;
        'flex-wrap': boolean;
        'flex-flow': boolean;
    };
    'flexbox-gap': any;
    'flow-root': any;
    'font-family-system-ui': any;
    'font-feature': {
        'font-feature-settings': boolean;
        'font-variant-ligatures': boolean;
        'font-language-override': boolean;
        'font-kerning': boolean;
    };
    'font-kerning': any;
    'font-loading': any;
    'font-size-adjust': {
        'font-size-adjust': boolean;
    };
    'font-smooth': any;
    'font-unicode-range': {
        'unicode-range': boolean;
    };
    'font-variant-alternates': any;
    'font-variant-numeric': any;
    fontface: ((rule: import('postcss').ChildNode) => boolean)[];
    fullscreen: (rule: import('postcss').ChildNode) => boolean;
    getcomputedstyle: any;
    'inline-block': {
        display: string;
    };
    'intrinsic-width': {
        width: string[];
        'min-width': string[];
        'max-width': string[];
        height: string[];
        'min-height': string[];
        'max-height': string[];
    };
    'justify-content-space-evenly': any;
    'kerning-pairs-ligatures': {
        'text-rendering': string;
    };
    'mdn-css-unicode-bidi-isolate': {
        'unicode-bidi': string;
    };
    'mdn-css-unicode-bidi-isolate-override': {
        'unicode-bidi': string;
    };
    'mdn-css-unicode-bidi-plaintext': {
        'unicode-bidi': string;
    };
    'mdn-text-decoration-color': {
        'text-decoration-color': boolean;
    };
    'mdn-text-decoration-line': {
        'text-decoration-line': boolean;
    };
    'mdn-text-decoration-shorthand': {
        'text-decoration': boolean;
    };
    'mdn-text-decoration-style': {
        'text-decoration-style': boolean;
    };
    minmaxwh: {
        'min-width': boolean;
        'max-width': boolean;
        'min-height': boolean;
        'max-height': boolean;
    };
    multibackgrounds: (rule: import('postcss').ChildNode) => boolean;
    multicolumn: {
        columns: boolean;
        'column-width': boolean;
        'column-gap': boolean;
        'column-rule': boolean;
        'column-rule-color': boolean;
        'column-rule-width': boolean;
        'column-count': boolean;
        'column-rule-style': boolean;
        'column-span': boolean;
        'column-fill': boolean;
        'break-before': boolean;
        'break-after': boolean;
        'break-inside': boolean;
    };
    'object-fit': {
        'object-fit': boolean;
        'object-position': boolean;
    };
    outline: {
        outline: boolean;
        'outline-style': boolean;
        'outline-width': boolean;
        'outline-color': boolean;
    };
    pointer: {
        'touch-action': boolean;
    };
    'pointer-events': {
        'pointer-events': boolean;
    };
    'prefers-color-scheme': any;
    'prefers-reduced-motion': any;
    rem: (rule: import('postcss').ChildNode) => boolean;
    'run-in': any;
    'style-scoped': any;
    'svg-css': any;
    'text-decoration': {
        'text-decoration-style': boolean;
        'text-decoration-line': boolean;
        'text-decoration-color': boolean;
        'text-decoration': RegExp;
        'text-decoration-thickness': boolean;
        'text-decoration-skip': boolean;
        'text-decoration-skip-ink': boolean;
    };
    'text-emphasis': any;
    'text-overflow': {
        'text-overflow': boolean;
    };
    'text-size-adjust': {
        'text-size-adjust': boolean;
    };
    'text-stroke': any;
    transforms2d: {
        transform: boolean;
        'transform-origin': boolean;
    };
    transforms3d: {
        perspective: boolean;
        'perspective-origin': boolean;
        'transform-style': boolean;
        'backface-visibility': boolean;
        transform: string;
    };
    ttf: any;
    'user-select-none': {
        'user-select': boolean;
    };
    'variable-fonts': any;
    'viewport-unit-variants': any;
    'viewport-units': {
        '': string[];
    };
    'webkit-user-drag': any;
    'will-change': {
        'will-change': boolean;
    };
    'word-break': {
        'word-break': boolean;
    };
    wordwrap: {
        'overflow-wrap': boolean;
        'word-wrap': boolean;
    };
};
